searchData={"items":[{"type":"module","doc":"Runs Non-Maximum Suppression (NMS) on a given Nx tensor (or directly a binary) using a Rust NIF.\n\nThe implementation expects a tensor with shape `{rows, columns}` or `{1, rows, columns}` where:\n- Each row represents a detection candidate.\n- The columns consist of bounding box parameters followed by class probabilities.\n  - The first 4 columns are the bounding box parameters: `cx` (center x), `cy` (center y), `w` (width), and `h` (height).\n  - The remaining columns are the class probabilities for each class. The number of columns is the number of classes.\n\nThe number of detection candidates (rows) and the number of columns (bounding box parameters + class probabilities) can vary depending on the model architecture.\nFor example, a YOLO model trained on the COCO dataset would have 80 class probabilities, resulting in a tensor with 84 columns (4 bbox parameters + 80 class probabilities). The number of rows is the number of detection candidates.\n\nIf your model outputs `{columns, rows}` (e.g., `{84, 8400}`), set `transpose: true` (default) in `run/2` options.","title":"YoloFastNMS","ref":"YoloFastNMS.html"},{"type":"function","doc":"Runs Non-Maximum Suppression (NMS) on an Nx tensor and returns a list of detected objects.","title":"YoloFastNMS.run/2","ref":"YoloFastNMS.html#run/2"},{"type":"function","doc":"- `tensor`: An `Nx.Tensor` with shape `{rows, columns}` or `{1, rows, columns}`. Each row is a detection candidate, with the first 4 columns as bounding box parameters (`cx`, `cy`, `w`, `h`) and the remaining columns as class probabilities.\n  - `options`: Keyword list of options:\n    - `:prob_threshold` (float, default: 0.25) — Minimum probability threshold for detection confidence.\n    - `:iou_threshold` (float, default: 0.5) — IoU threshold for overlap suppression.\n    - `:transpose` (boolean, default: true) — Whether to transpose the input tensor (set to true if your tensor shape is `{columns, rows}`).","title":"Parameters - YoloFastNMS.run/2","ref":"YoloFastNMS.html#run/2-parameters"},{"type":"function","doc":"- A list of lists `[cx, cy, w, h, prob, class_idx]` for each detected object, where:\n    - `cx`, `cy`: Center coordinates of the bounding box.\n    - `w`, `h`: Width and height of the bounding box.\n    - `prob`: Confidence score (0..1).\n    - `class_idx`: Index of the detected class.","title":"Returns - YoloFastNMS.run/2","ref":"YoloFastNMS.html#run/2-returns"},{"type":"function","doc":"Runs Non-Maximum Suppression (NMS) directly on a binary containing detection data.","title":"YoloFastNMS.run_with_binary/6","ref":"YoloFastNMS.html#run_with_binary/6"},{"type":"function","doc":"- `tensor_binary`: A binary containing detection data in shape `{rows, columns}` where:\n  - The first 4 columns contain bounding box parameters (cx, cy, w, h)\n  - The remaining columns contain class probabilities\n- `prob_threshold` - Minimum probability threshold (0..1) for detection confidence\n- `iou_threshold` - IoU threshold (0..1) for overlap detection\n- `rows` - Number of rows in the tensor\n- `columns` - Number of columns in the tensor\n- `transpose` - Whether to transpose the input tensor\n\nReturns a list of lists `[cx, cy, w, h, prob, class_idx]` where:\n- `cx`, `cy`: Center position coordinates of the detected object\n- `w`, `h`: Width and height of the bounding box\n- `prob`: Confidence score (between 0 and 1)\n- `class_idx`: Index of the detected class","title":"Parameters - YoloFastNMS.run_with_binary/6","ref":"YoloFastNMS.html#run_with_binary/6-parameters"},{"type":"extras","doc":"# YoloFastNMS\n\nA fast Non-Maximum Suppression (NMS) implementation in Rust for YOLO object detection outputs. This library is designed as a companion to the [`yolo`](https://github.com/poeticoding/yolo_elixir) library, specifically optimizing one of the most computationally intensive parts of the YOLO detection pipeline in Elixir/Nx, running much faster (~100x, ~4ms vs ~400ms on my MacBook Air M3)!\n\nThe NMS operation is crucial for filtering overlapping bounding boxes in object detection, but is computationally expensive when implemented in Elixir/Nx. This Rust NIF implementation provides significant speed improvements over the pure Elixir version, helping achieve near real-time performance for object detection tasks.\n\nThe current version is specifically built around YOLOv8 models trained on the COCO dataset, which outputs tensors in the shape of `{84, 8400}` (4 bounding box coordinates + 80 class probabilities × 8400 detections). The library efficiently filters these detections based on confidence scores `prob_threshold` and Intersection over Union (IoU) `iou_threshold` thresholds. Future development will focus on making the number of classes and detections dynamic, enabling compatibility with different YOLO and custom models.","title":"YoloFastNMS","ref":"readme.html"},{"type":"extras","doc":"```elixir\ndef deps do\n  [\n    {:yolo_fast_nms, \"~> 0.1.0\"}\n  ]\nend\n```","title":"Installation - YoloFastNMS","ref":"readme.html#installation"},{"type":"extras","doc":"```elixir\n{84, 8400} = tensor_nx.shape\niex> YoloFastNMS.run(tensor_nx, 0.4, 0.5)\n[\n  [cx, cy, w, h, prob, class_idx]\n  ...\n] \n```","title":"Stand-alone usage - YoloFastNMS","ref":"readme.html#stand-alone-usage"},{"type":"extras","doc":"```elixir\nmodel = YOLO.load(...)\n\nYOLO.detect(mat, nms_fun: &YoloFastNMS.run/3)\n```","title":"With YOLO library - YoloFastNMS","ref":"readme.html#with-yolo-library"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}